import React, { useState, useEffect } from 'react';
import styles from './index.less';
import { Row, Col, Image, Pagination, Card, Tag } from 'antd';
import { useRequest } from 'ahooks';
import { doFetch } from '@/utils/doFetch';
import { EyeFilled } from '@ant-design/icons';
import { history } from 'umi';

const col = { xs: 24, sm: 12, md: 12, lg: 8, xl: 8, xxl: 6 };
const { Meta } = Card;

function Join() {
  const { data, loading } = useRequest(async () => {
    let data = await doFetch({
      url: '/recruit/limitList',
      params: { limitNum: 1000 },
    });
    return data?.data?.dataList;
  });

  const onChange = (pageIndex, pageSize) => {
    setpage({
      pageIndex,
      pageSize,
    });
  };

  return (
    <div className="section">
      <h2 className="title">招聘岗位</h2>
      <p style={{ textAlign: 'center', fontSize: '0.6rem' }}>
        如果您对我们感兴趣，欢迎投递简历至
        <a href="mailto:chenjie@jsnangao.com" target="_blank">
          chenjie@jsnangao.com
        </a>
        ，邮件主题格式：<a>岗位名称+姓名+学校+学历，</a>更多招聘信息请详询：
        <a href="tel:025-52187179">025-52187179</a>，期待您的加入！
      </p>
      <Row gutter={24}>
        {data?.map?.((it, i) => {
          return (
            <Col {...col} style={{ marginBottom: 24 }}>
              <Card
                hoverable
                style={{
                  width: '100%',
                }}
                onClick={() => {
                  history.push({
                    pathname: '/about/newsdetail',
                    query: {
                      id: it.id,
                    },
                  });
                }}
              >
                <p
                  style={{
                    fontSize: '0.8rem',
                    width: '100%',
                    marginTop: '1rem',
                  }}
                  className="spread"
                >
                  <span>{it?.positionName}</span>
                  <span style={{ color: 'rgba(255, 103, 47, 1)' }}>
                    {it?.salary}
                  </span>
                </p>
                <div className="centerl">
                  {it.positionDepartment && (
                    <Tag
                      color="blue"
                      style={{ fontSize: '0.6rem', padding: '0.2rem' }}
                    >
                      {it.positionDepartment}
                    </Tag>
                  )}
                  {it.education && (
                    <Tag
                      color="cyan"
                      style={{ fontSize: '0.6rem', padding: '0.2rem' }}
                    >
                      {it.education}
                    </Tag>
                  )}
                  {it.wordExperience && (
                    <Tag
                      color="geekblue"
                      style={{ fontSize: '0.6rem', padding: '0.2rem' }}
                    >
                      {it.wordExperience}
                    </Tag>
                  )}
                </div>
                <div className="centerl" style={{ marginTop: '1rem' }}>
                  <div
                    style={{
                      backgroundColor: '#f0f0f0',
                      padding: '6px 12px',
                      fontSize: '0.6rem',
                      display: 'inline-block',
                      width: '4rem',
                    }}
                    classNam="center"
                  >
                    <span>
                      <span
                        style={{
                          fontSize: '1.2rem',
                          color: 'rgba(12, 100, 201, 1)',
                          marginRight: 6,
                        }}
                      >
                        {it?.hiringNum}
                      </span>
                      人
                    </span>
                    <br />
                    <span>招聘人数</span>
                  </div>
                  <div
                    style={{
                      backgroundColor: '#f0f0f0',
                      padding: '6px 12px',
                      fontSize: '0.6rem',
                      display: 'inline-block',
                      marginLeft: '1rem',
                    }}
                    classNam="center"
                  >
                    <span>工作地点</span>
                    <br />
                    <span
                      style={{
                        fontSize: '0.4rem',
                        color: 'rgba(12, 100, 201, 1)',
                        marginRight: 6,
                      }}
                    >
                      {it?.workAddress}
                    </span>
                  </div>
                </div>
              </Card>
            </Col>
          );
        })}
      </Row>
    </div>
  );
}

export default Join;
